==> ideaIC-172.1909.2-sources.jar: com/intellij/vcs/log/history/FileHistoryVisiblePack.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.vcs.log.history;

import com.intellij.vcs.log.VcsLogFilterCollection;
import com.intellij.vcs.log.data.DataPackBase;
import com.intellij.vcs.log.data.index.IndexDataGetter;
import com.intellij.vcs.log.graph.VisibleGraph;
import com.intellij.vcs.log.visible.VisiblePack;
import org.jetbrains.annotations.NotNull;

public class FileHistoryVisiblePack extends VisiblePack {
  @NotNull private final IndexDataGetter.FileNamesData myNamesData;

  public FileHistoryVisiblePack(@NotNull DataPackBase dataPack,
                                @NotNull VisibleGraph<Integer> graph,
                                boolean canRequestMore,
                                @NotNull VcsLogFilterCollection filters,
                                @NotNull IndexDataGetter.FileNamesData namesData) {
    super(dataPack, graph, canRequestMore, filters);
    myNamesData = namesData;
  }

  @NotNull
  public IndexDataGetter.FileNamesData getNamesData() {
    return myNamesData;
  }
}

==> ideaIC-182.4323.18-sources.jar: com/intellij/vcs/log/history/FileHistoryVisiblePack.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.vcs.log.history;

import com.intellij.openapi.vcs.FilePath;
import com.intellij.vcs.log.VcsLogFilterCollection;
import com.intellij.vcs.log.data.DataPackBase;
import com.intellij.vcs.log.graph.VisibleGraph;
import com.intellij.vcs.log.visible.VisiblePack;
import org.jetbrains.annotations.NotNull;

import java.util.Map;

public class FileHistoryVisiblePack extends VisiblePack {
  @NotNull private final Map<Integer, FilePath> myNamesData;

  public FileHistoryVisiblePack(@NotNull DataPackBase dataPack,
                                @NotNull VisibleGraph<Integer> graph,
                                boolean canRequestMore,
                                @NotNull VcsLogFilterCollection filters,
                                @NotNull Map<Integer, FilePath> namesData) {
    super(dataPack, graph, canRequestMore, filters);
    myNamesData = namesData;
  }

  @NotNull
  public Map<Integer, FilePath> getNamesData() {
    return myNamesData;
  }
}
